import {AdRecord} from "../records/ad.record";
import {AdEntity} from "../types";
import {pool} from "../utils/db";

const defaultObj = {
    id: 'qwerty',
    name: "[Test]Dodawanko",
    description: "Dodany w teście Ad",
    price: 12,
    url: "https://dom-weselny-grzesiu.pl",
    lat: 34.22,
    lon: 1.55123
}

afterAll(async () => {
   await pool.end();
});


test('AdRecord returns data from database for one entry.', async () => {
    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('Testowa');
})

test('AdRecord returns null from database for unexisting entry.', async () => {

    const ad = await AdRecord.getOne('----');

    expect(ad).toBeNull();

})

test('AdRecord.insert returns new UUID', async () => {
    const newAd: AdRecord = new AdRecord(defaultObj)

    await newAd.insert();

    expect(newAd.id).toBeDefined();
    expect(typeof newAd.id).toBe('string');
})

test('AdRecord.insert inserts data to database.', async () => {
    const newAd: AdRecord = new AdRecord(defaultObj)
    await newAd.insert();

    const foundAd = await AdRecord.getOne(newAd.id);

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(newAd.id);
})

test('AdRecord.findAll returns array of found entries', async () => {
    const ads = await AdRecord.getCorrect('');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll returns array of found entries when searching for "a"', async () => {
    const ads = await AdRecord.getCorrect('a');
    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll returns empty array when searching for something that does not exist', async () => {
    const ads = await AdRecord.getCorrect('---------------------uihijnln------');
    expect(ads).toEqual([]);
})

test('AdRecord.findAll returns smaller amount of data.', async () => {
    const ads = await AdRecord.getCorrect('est');
    expect((ads[0] as AdEntity).price).toBeUndefined();
})

test('Can list and find Ad?', async () => {
    const ads = await AdRecord.getCorrect('est')
    expect(ads[0]).toBeDefined();
})